@@ -1,4 +1,4 @@
-from chatgpt_cli.conversation import Conversation
+from chatgpt_cli.conversation import Conversation, Template
 from utils.io import *
 
 
@@ -9,8 +9,9 @@ def is_command(user_msg: str) -> bool:
 
 
 def execute_command(
-        user_msg: str,
-        conv: Conversation,
+    user_msg: str,
+    conv: Conversation,
+    tmpl: Template,
 ) -> str:
     user_msg = user_msg.strip()
     if user_msg in ["!help", "help"]:
@@ -37,6 +38,8 @@ def execute_command(
         conv.save(True)
         print("Bye!")
         exit(0)
+    elif user_msg.startswith("!tmpl"):
+        tmpl.execute_command(user_msg, conv)
     elif user_msg.startswith("!"):
         print("Invalid command, please try again")
     return user_msg
