@@ -102,8 +102,11 @@ def user_input(prompt="\nUser: ") -> str:
         # Update the prompt using readline
         prompt = "\r" + " " * len(prompt) + "\r" + " .... " + readline.get_line_buffer()
     # Print a message indicating that the input has been submitted
-    msg = "\n".join(lines)
-    printmd("**[Input Submitted]**")
+    msg = "\n".join(lines).strip()
+    if msg:
+        printmd("**[Input Submitted]**")
+    else:
+        printmd("**[Empty Input Skipped]**")
     return msg
 
 
